rdacca.mhp: Hierarchical Partitioning for Canonical Analysis by...

rdacca.mhpR Documentation

Hierarchical Partitioning for Canonical Analysis by Explanatory Matrices

Description

Hierarchical Partitioning for Canonical Analysis by Explanatory Matrices

Usage

rdacca.mhp(
  dv,
  iv,
  method = c("RDA", "dbRDA", "CCA"),
  type = c("adjR2", "R2"),
  trace = FALSE,
  plot.perc = FALSE
)

Arguments

dv

Data frame or matrix containing the response data table or dissimilarity structure inheriting from dist. In community ecology, that table is often a site-by-species table or a dissimilarity object.

iv

A list containing N groups explanatory data frame or matrix.

method

The type of canonical analysis: RDA, dbRDA or CCA, the default is "RDA".

type

The type of total explained variation: "adjR2" is adjusted R-squared and "R2" for unadjusted R-squared, the default is "adjR2".

trace

logical value, if TRUE, the vaules of commonality (2^N-1for N group of explanatory variables) are outputed,the default is FALSE.

plot.perc

logical value, if TRUE, the bar plot (based on ggplot2) of the percentage to independent effects of variables group to total Rsquared, the default is FALSE to show plot with original independent effects.

Details

This function calculates the independent contribution of each explanatory group to explained variation (R-squared) on canonical analysis (RDA,CCA and dbRDA), applying the hierarchy algorithm of Chevan and Sutherland (1991). The algorithm is that all joint R-squared will be decomposed into equal fractions by number of involved explanatory groups and average assigned to these group. Independent R-squared of each variable will be the sum of assigned R-squared from joint R-squared and unique R-squared.

Value

a list containing

Method_Type

The type of canonical analysis and the type of total explained variation.

R.squared

The explained variation for global model.

Commonality

If trace=TRUE,a mtrix listing tha value and percentage of all commonality (2^N-1 for N explanatory variables groups).

Var.part

A matrix listing independent effect and its percentage to total explained variation for each explanatory variable group.

Author(s)

Jiangshan Lai lai@ibcas.ac.cn

Pedro Peres-Neto pedro.peres-neto@concordia.ca

Examples

require(vegan)
data(mite)
data(mite.env)
data(mite.xy)
data(mite.pcnm)
mite.hel <- decostand(mite, "hellinger")
iv <- list(env=mite.env,xy=mite.xy,pcnm=mite.pcnm)
rdacca.mhp(mite.hel,iv,method="RDA",trace = TRUE,plot.perc = FALSE)
rdacca.mhp(vegdist(mite),iv,method="dbRDA",trace = TRUE,plot.perc = FALSE)
rdacca.mhp(mite,iv,method="CCA",trace = TRUE,plot.perc = FALSE)

laijiangshan/rdacca.hp documentation built on Feb. 22, 2025, 9:43 a.m.